@@ -12,6 +12,7 @@ import (
 	"strings"
 
 	genq "github.com/Khan/genqlient/graphql"
+	"github.com/superfly/flyctl/terminal"
 	"github.com/superfly/graphql"
 )
 
@@ -41,7 +42,6 @@ type Client struct {
 
 // NewClient - creates a new Client, takes an access token
 func NewClient(accessToken, name, version string, logger Logger) *Client {
-
 	httpClient, _ := NewHTTPClient(logger, http.DefaultTransport)
 
 	url := fmt.Sprintf("%s/graphql", baseURL)
@@ -56,7 +56,7 @@ func NewClient(accessToken, name, version string, logger Logger) *Client {
 }
 
 // NewRequest - creates a new GraphQL request
-func (c *Client) NewRequest(q string) *graphql.Request {
+func (*Client) NewRequest(q string) *graphql.Request {
 	q = compactQueryString(q)
 	return graphql.NewRequest(q)
 }
@@ -118,7 +118,12 @@ func GetAccessToken(ctx context.Context, email, password, otp string) (token str
 	if res, err = http.DefaultClient.Do(req); err != nil {
 		return
 	}
-	defer res.Body.Close()
+	defer func() {
+		err := res.Body.Close()
+		if err != nil {
+			terminal.Errorf("error closing response body: %v", err)
+		}
+	}()
 
 	switch {
 	case res.StatusCode >= http.StatusInternalServerError:
