@@ -15,6 +15,7 @@ var configPatches = []patchFuncType{
 	patchServices,
 	patchProcesses,
 	patchExperimental,
+	patchMounts,
 }
 
 func applyPatches(cfgMap map[string]any) (*Config, error) {
@@ -243,6 +244,15 @@ func ensureArrayOfMap(raw any) ([]map[string]any, error) {
 	return out, nil
 }
 
+func patchMounts(cfg map[string]any) (map[string]any, error) {
+	if mount, ok := cfg["mount"]; ok {
+		cfg["mounts"] = mount
+	}
+	delete(cfg, "mount")
+	return cfg, nil
+
+}
+
 func stringOrSliceToSlice(input any, fieldName string) ([]string, error) {
 	if input == nil {
 		return nil, nil
