@@ -35,7 +35,7 @@ func newAttach() *cobra.Command {
 	const (
 		short = "Attach a postgres cluster to an app"
 		long  = short + "\n"
-		usage = "attach [POSTGRES APP]"
+		usage = "attach <POSTGRES APP>"
 	)
 
 	cmd := command.New(usage, short, long, runAttach,
