@@ -11,6 +11,8 @@ import (
 	"github.com/pkg/errors"
 )
 
+var healthcheck_channel = make(chan string)
+
 func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	if !checksPass(sourceDir, dirContains("Gemfile", "rails")) {
 		return nil, nil
@@ -64,6 +66,18 @@ https://fly.io/docs/rails/getting-started/dockerfiles/.
 Once ready: run 'fly deploy' to deploy your Rails app.
 `
 
+	// fetch healthcheck route in a separate thread
+	go func() {
+		out, err := exec.Command("ruby", "./bin/rails", "runner",
+			"puts Rails.application.routes.url_helpers.rails_health_check_path").Output()
+
+		if err == nil {
+			healthcheck_channel <- strings.TrimSpace(string(out))
+		} else {
+			healthcheck_channel <- ""
+		}
+	}()
+
 	return s, nil
 }
 
@@ -156,5 +170,7 @@ func RailsCallback(srcInfo *SourceInfo, options map[string]bool) error {
 		},
 	}
 
+	srcInfo.HttpCheckPath = <-healthcheck_channel
+
 	return nil
 }
